---
title: Home
---
# snippy-ng

[![PyPI - Version](https://img.shields.io/pypi/v/snippy-ng.svg)](https://pypi.org/project/snippy-ng)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/snippy-ng.svg)](https://pypi.org/project/snippy-ng)
[![Benchmark](https://byob.yarr.is/centre-pathogen-genomics/snippy-ng/benchmark)](https://github.com/centre-pathogen-genomics/snippy-ng/actions/workflows/benchmark.yaml)
-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install snippy-ng
```

## License

`snippy-ng` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
